@@ -9,7 +9,7 @@ from .cache import *
 from .zeromq.dispatcher import Dispatcher as zmqc
 from .db.dispatcher import PgDispatcher as pgsqlc, CouchDBDispatcher as couchdbc, RedisDBDispatcher as redisc
 from .auth.backends import authenticate_container as authenticate
-from .mqtt.dispatcher import MqttDispatcher as mqttc
+from .mqtt.dispatcher import Dispatcher as mqttc
 from .views.containers import Response
 
 envoxy = locals()
