@@ -23,6 +23,17 @@ class Singleton(object):
         
         return cls.__instance
 
+    @classmethod
+    def instance_with_queue(cls, queue_):
+        
+        if not cls.__instance:
+            
+            with cls.__lock:
+                if not cls.__instance:
+                    cls.__instance = cls(queue_=queue_)
+        
+        return cls.__instance
+
 
 # A per-thread container implementation of Singleton pattern
 # To be used as mixin or base class
@@ -40,3 +51,13 @@ class SingletonPerThread(object):
             cls.__instances[_thread_id] = cls()
         
         return cls.__instances[_thread_id]
+
+    @classmethod
+    def instance_with_queue(cls, queue_):
+        
+        _thread_id = threading.get_ident()
+        
+        if _thread_id not in cls.__instances:
+            cls.__instances[_thread_id] = cls(queue_=queue_)
+        
+        return cls.__instances[_thread_id]
